@@ -281,7 +281,7 @@ modulemd_module_stream_v2_equals (ModulemdModuleStream *self_1,
 
 
 static guint64
-modulemd_module_stream_v2_get_mdversion (ModulemdModuleStream *self)
+modulemd_module_stream_v2_get_mdversion (ModulemdModuleStream *UNUSED (self))
 {
   return MD_MODULESTREAM_VERSION_TWO;
 }
@@ -1263,6 +1263,15 @@ modulemd_module_stream_v2_get_xmd (ModulemdModuleStreamV2 *self)
 }
 
 
+void
+modulemd_module_stream_v2_clear_xmd (ModulemdModuleStreamV2 *self)
+{
+  g_return_if_fail (MODULEMD_IS_MODULE_STREAM_V2 (self));
+
+  g_clear_pointer (&self->xmd, g_variant_unref);
+}
+
+
 gboolean
 modulemd_module_stream_v2_includes_nevra (ModulemdModuleStreamV2 *self,
                                           const gchar *nevra_pattern)
@@ -1652,7 +1661,7 @@ depends_on_stream (ModulemdModuleStreamV2 *self,
   ModulemdDependencies *dep = NULL;
 
   /* Iterate through all of the dependency objects */
-  for (gint i = 0; i < self->dependencies->len; i++)
+  for (guint i = 0; i < self->dependencies->len; i++)
     {
       dep = g_ptr_array_index (self->dependencies, i);
       if (is_builddep)
@@ -3074,9 +3083,9 @@ modulemd_module_stream_v2_emit_yaml (ModulemdModuleStreamV2 *self,
       EMIT_KEY_VALUE (emitter, error, "static_context", "true");
     }
 
-  EMIT_KEY_VALUE_IF_SET (
+  EMIT_KEY_VALUE_STRING_IF_SET (
     emitter, error, "arch", modulemd_module_stream_v2_get_arch (self));
-  EMIT_KEY_VALUE (emitter, error, "summary", self->summary);
+  EMIT_KEY_VALUE_STRING (emitter, error, "summary", self->summary);
   EMIT_KEY_VALUE_FULL (emitter,
                        error,
                        "description",
@@ -3124,10 +3133,11 @@ modulemd_module_stream_v2_emit_yaml (ModulemdModuleStreamV2 *self,
     {
       EMIT_SCALAR (emitter, error, "references");
       EMIT_MAPPING_START (emitter, error);
-      EMIT_KEY_VALUE_IF_SET (emitter, error, "community", self->community);
-      EMIT_KEY_VALUE_IF_SET (
+      EMIT_KEY_VALUE_STRING_IF_SET (
+        emitter, error, "community", self->community);
+      EMIT_KEY_VALUE_STRING_IF_SET (
         emitter, error, "documentation", self->documentation);
-      EMIT_KEY_VALUE_IF_SET (emitter, error, "tracker", self->tracker);
+      EMIT_KEY_VALUE_STRING_IF_SET (emitter, error, "tracker", self->tracker);
       EMIT_MAPPING_END (emitter, error);
     }
 
