@@ -85,7 +85,8 @@ modulemd_module_copy (ModulemdModule *self)
 
 
 gboolean
-modulemd_module_validate (ModulemdModule *self, GError **error)
+modulemd_module_validate (ModulemdModule *UNUSED (self),
+                          GError **UNUSED (error))
 {
   /* No validation yet */
   return TRUE;
@@ -206,12 +207,12 @@ modulemd_module_set_defaults (ModulemdModule *self,
   g_autoptr (GError) nested_error = NULL;
   g_return_val_if_fail (MODULEMD_IS_MODULE (self), MD_DEFAULTS_VERSION_ERROR);
 
-  g_clear_object (&self->defaults);
   if (defaults == NULL)
     {
-      /* If we are empty here, return MD_DEFAULTS_VERSION_UNSET so the
-       * function reports success and does not influence further upgrades.
+      /* If we are empty here, return MD_DEFAULTS_VERSION_UNSET to report
+       * a successful unsetting.
        */
+      g_clear_object (&self->defaults);
       return MD_DEFAULTS_VERSION_UNSET;
     }
 
@@ -237,7 +238,7 @@ modulemd_module_set_defaults (ModulemdModule *self,
    * We only call this if the mdversion is definitely lower, because the
    * upgrade() routine is not designed to handle downgrades.
    */
-  if (modulemd_defaults_get_mdversion (defaults) < index_mdversion)
+  if (modulemd_defaults_get_mdversion (defaults) < (guint64)index_mdversion)
     {
       upgraded_defaults =
         modulemd_defaults_upgrade (defaults, index_mdversion, &nested_error);
@@ -259,6 +260,7 @@ modulemd_module_set_defaults (ModulemdModule *self,
   /* Return the mdversion we saved so that the Index can check to see if we
    * need to upgrade other modules to match.
    */
+  g_clear_object (&self->defaults);
   self->defaults = g_steal_pointer (&upgraded_defaults);
   return modulemd_defaults_get_mdversion (self->defaults);
 }
@@ -389,7 +391,7 @@ modulemd_module_add_stream (ModulemdModule *self,
       return MD_MODULESTREAM_VERSION_ERROR;
     }
 
-  if (modulemd_module_stream_get_mdversion (stream) < index_mdversion)
+  if (modulemd_module_stream_get_mdversion (stream) < (guint64)index_mdversion)
     {
       /* If the stream we were passed is of a lower mdversion version than the
        * index, upgrade it to the index version.
@@ -1086,3 +1088,23 @@ modulemd_module_get_newest_active_obsoletes (ModulemdModule *self,
 
   return newestActiveObsoletes;
 }
+
+
+static void
+clear_xmds (gpointer data, gpointer user_data)
+{
+  g_return_if_fail (MODULEMD_IS_MODULE_STREAM_V2 (data));
+
+  modulemd_module_stream_v2_clear_xmd (MODULEMD_MODULE_STREAM_V2 (data));
+}
+
+
+void
+modulemd_module_clear_xmds (ModulemdModule *self)
+{
+  MODULEMD_INIT_TRACE ();
+
+  g_return_if_fail (MODULEMD_IS_MODULE (self));
+
+  g_ptr_array_foreach (self->streams, clear_xmds, NULL);
+}
