@@ -627,7 +627,7 @@ modulemd_obsoletes_class_init (ModulemdObsoletesClass *klass)
 }
 
 static void
-modulemd_obsoletes_init (ModulemdObsoletes *self)
+modulemd_obsoletes_init (ModulemdObsoletes *UNUSED (self))
 {
 }
 
@@ -635,7 +635,6 @@ modulemd_obsoletes_init (ModulemdObsoletes *self)
 static gboolean
 modulemd_obsoletes_parse_obsoleted_by (yaml_parser_t *parser,
                                        ModulemdObsoletes *o,
-                                       gboolean strict,
                                        GError **error)
 {
   MODULEMD_INIT_TRACE ();
@@ -660,7 +659,7 @@ modulemd_obsoletes_parse_obsoleted_by (yaml_parser_t *parser,
         case YAML_MAPPING_END_EVENT: done = TRUE; break;
 
         case YAML_SCALAR_EVENT:
-          if (g_str_equal (event.data.scalar.value, "module"))
+          if (g_str_equal ((const gchar *)event.data.scalar.value, "module"))
             {
               if (modulemd_obsoletes_get_obsoleted_by_module_name (o))
                 {
@@ -687,7 +686,7 @@ modulemd_obsoletes_parse_obsoleted_by (yaml_parser_t *parser,
               g_clear_pointer (&value, g_free);
             }
 
-          if (g_str_equal (event.data.scalar.value, "stream"))
+          if (g_str_equal ((const gchar *)event.data.scalar.value, "stream"))
             {
               if (modulemd_obsoletes_get_obsoleted_by_module_stream (o))
                 {
@@ -738,8 +737,6 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
   gboolean done = FALSE;
 
   g_autofree gchar *value = NULL;
-  g_autofree gchar *obs_by_mod_name = NULL;
-  g_autofree gchar *obs_by_mod_stream = NULL;
   guint64 modified;
   guint64 eol_date;
   gboolean reset;
@@ -786,7 +783,7 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
         case YAML_MAPPING_END_EVENT: done = TRUE; break;
 
         case YAML_SCALAR_EVENT:
-          if (g_str_equal (event.data.scalar.value, "module"))
+          if (g_str_equal ((const gchar *)event.data.scalar.value, "module"))
             {
               if (!g_str_equal (modulemd_obsoletes_get_module_name (o),
                                 O_PLACEHOLDER_STRING))
@@ -814,7 +811,8 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
               modulemd_obsoletes_set_module_name (o, value);
               g_clear_pointer (&value, g_free);
             }
-          else if (g_str_equal (event.data.scalar.value, "stream"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "stream"))
             {
               if (!g_str_equal (modulemd_obsoletes_get_module_stream (o),
                                 O_PLACEHOLDER_STRING))
@@ -835,7 +833,8 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
               modulemd_obsoletes_set_module_stream (o, value);
               g_clear_pointer (&value, g_free);
             }
-          else if (g_str_equal (event.data.scalar.value, "context"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "context"))
             {
               if (modulemd_obsoletes_get_module_context (o))
                 {
@@ -855,7 +854,8 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
               modulemd_obsoletes_set_module_context (o, value);
               g_clear_pointer (&value, g_free);
             }
-          else if (g_str_equal (event.data.scalar.value, "modified"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "modified"))
             {
               value = modulemd_yaml_parse_string (&parser, &nested_error);
               if (nested_error)
@@ -880,7 +880,8 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
               modulemd_obsoletes_set_modified (o, modified);
               g_clear_pointer (&value, g_free);
             }
-          else if (g_str_equal (event.data.scalar.value, "eol_date"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "eol_date"))
             {
               value = modulemd_yaml_parse_string (&parser, &nested_error);
               if (nested_error)
@@ -906,7 +907,8 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
               modulemd_obsoletes_set_eol_date (o, eol_date);
               g_clear_pointer (&value, g_free);
             }
-          else if (g_str_equal (event.data.scalar.value, "reset"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "reset"))
             {
               reset = modulemd_yaml_parse_bool (&parser, &nested_error);
               if (nested_error)
@@ -920,7 +922,8 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
 
               modulemd_obsoletes_set_reset (o, reset);
             }
-          else if (g_str_equal (event.data.scalar.value, "message"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "message"))
             {
               if (!g_str_equal (modulemd_obsoletes_get_message (o),
                                 O_PLACEHOLDER_STRING))
@@ -941,10 +944,11 @@ modulemd_obsoletes_parse_yaml (ModulemdSubdocumentInfo *subdoc,
               modulemd_obsoletes_set_message (o, value);
               g_clear_pointer (&value, g_free);
             }
-          else if (g_str_equal (event.data.scalar.value, "obsoleted_by"))
+          else if (g_str_equal ((const gchar *)event.data.scalar.value,
+                                "obsoleted_by"))
             {
               if (!modulemd_obsoletes_parse_obsoleted_by (
-                    &parser, o, strict, &nested_error))
+                    &parser, o, &nested_error))
                 {
                   g_propagate_error (error, g_steal_pointer (&nested_error));
                   return NULL;
@@ -1006,11 +1010,11 @@ modulemd_obsoletes_emit_obsoleted_by (ModulemdObsoletes *self,
       return FALSE;
     }
 
-  if (!mmd_emitter_scalar (emitter,
-                           modulemd_obsoletes_get_obsoleted_by_module_name (
-                             MODULEMD_OBSOLETES (self)),
-                           YAML_PLAIN_SCALAR_STYLE,
-                           error))
+  if (!mmd_emitter_scalar_string (
+        emitter,
+        modulemd_obsoletes_get_obsoleted_by_module_name (
+          MODULEMD_OBSOLETES (self)),
+        error))
     {
       return FALSE;
     }
@@ -1114,10 +1118,9 @@ modulemd_obsoletes_emit_yaml (ModulemdObsoletes *self,
       return FALSE;
     }
 
-  if (!mmd_emitter_scalar (
+  if (!mmd_emitter_scalar_string (
         emitter,
         modulemd_obsoletes_get_module_name (MODULEMD_OBSOLETES (self)),
-        YAML_PLAIN_SCALAR_STYLE,
         error))
     {
       return FALSE;
@@ -1149,8 +1152,7 @@ modulemd_obsoletes_emit_yaml (ModulemdObsoletes *self,
           return FALSE;
         }
 
-      if (!mmd_emitter_scalar (
-            emitter, module_context, YAML_PLAIN_SCALAR_STYLE, error))
+      if (!mmd_emitter_scalar_string (emitter, module_context, error))
         {
           return FALSE;
         }
@@ -1179,10 +1181,9 @@ modulemd_obsoletes_emit_yaml (ModulemdObsoletes *self,
       return FALSE;
     }
 
-  if (!mmd_emitter_scalar (
+  if (!mmd_emitter_scalar_string (
         emitter,
         modulemd_obsoletes_get_message (MODULEMD_OBSOLETES (self)),
-        YAML_PLAIN_SCALAR_STYLE,
         error))
     {
       return FALSE;
