@@ -336,7 +336,7 @@ modulemd_packager_v3_get_xmd (ModulemdPackagerV3 *self)
 
 
 guint64
-modulemd_packager_v3_get_mdversion (ModulemdPackagerV3 *self)
+modulemd_packager_v3_get_mdversion (ModulemdPackagerV3 *UNUSED (self))
 {
   return MD_PACKAGER_VERSION_THREE;
 }
@@ -825,6 +825,28 @@ modulemd_packager_v3_to_defaults (ModulemdPackagerV3 *self,
       profile = MODULEMD_PROFILE (value);
       if (modulemd_profile_is_default (profile))
         {
+          if (!self->module_name)
+            {
+              g_set_error (
+                error,
+                MODULEMD_ERROR,
+                MMD_ERROR_MISSING_REQUIRED,
+                "A module name is required when generating "
+                "a modulemd-defaults document for a default profile %s",
+                modulemd_profile_get_name (profile));
+              return FALSE;
+            }
+          if (!self->stream_name)
+            {
+              g_set_error (
+                error,
+                MODULEMD_ERROR,
+                MMD_ERROR_MISSING_REQUIRED,
+                "A module stream is required when generating "
+                "a modulemd-defaults document for a default profile %s",
+                modulemd_profile_get_name (profile));
+              return FALSE;
+            }
           if (!defaults)
             {
               defaults = modulemd_defaults_v1_new (self->module_name);
@@ -1403,6 +1425,7 @@ modulemd_packager_v3_parse_build_configs (yaml_parser_t *parser,
   gboolean done = FALSE;
   g_autoptr (ModulemdBuildConfig) buildconfig = NULL;
   g_autoptr (GError) nested_error = NULL;
+  const gchar *context;
 
   YAML_PARSER_PARSE_WITH_EXIT_BOOL (parser, &event, error);
   if (event.type != YAML_SEQUENCE_START_EVENT)
@@ -1427,6 +1450,18 @@ modulemd_packager_v3_parse_build_configs (yaml_parser_t *parser,
               g_propagate_error (error, g_steal_pointer (&nested_error));
               return FALSE;
             }
+          /* A context must be unique. We check explicitly here because glib2
+           * < 2.40 does not distinguish a replacement from an addition. */
+          context = modulemd_build_config_get_context (buildconfig);
+          if (g_hash_table_contains (packager->build_configs, context))
+            {
+              g_set_error (error,
+                           MODULEMD_ERROR,
+                           MMD_ERROR_VALIDATE,
+                           "Duplicate context: %s",
+                           context);
+              return FALSE;
+            }
           modulemd_packager_v3_add_build_config (packager, buildconfig);
           g_clear_object (&buildconfig);
           break;
@@ -1837,7 +1872,6 @@ modulemd_packager_v3_emit_yaml (ModulemdPackagerV3 *self,
                                 GError **error)
 {
   MODULEMD_INIT_TRACE ();
-  g_autoptr (GError) nested_error = NULL;
   gsize i;
   g_autoptr (GPtrArray) keys = NULL;
   gboolean ret;
@@ -1915,10 +1949,11 @@ modulemd_packager_v3_emit_yaml (ModulemdPackagerV3 *self,
     {
       EMIT_SCALAR (emitter, error, "references");
       EMIT_MAPPING_START (emitter, error);
-      EMIT_KEY_VALUE_IF_SET (emitter, error, "community", self->community);
-      EMIT_KEY_VALUE_IF_SET (
+      EMIT_KEY_VALUE_STRING_IF_SET (
+        emitter, error, "community", self->community);
+      EMIT_KEY_VALUE_STRING_IF_SET (
         emitter, error, "documentation", self->documentation);
-      EMIT_KEY_VALUE_IF_SET (emitter, error, "tracker", self->tracker);
+      EMIT_KEY_VALUE_STRING_IF_SET (emitter, error, "tracker", self->tracker);
       EMIT_MAPPING_END (emitter, error);
     }
 
