@@ -11,6 +11,7 @@
  * For more information on free software, see <https://www.gnu.org/philosophy/free-sw.en.html>.
  */
 
+#include "config.h"
 #include "modulemd-errors.h"
 #include "private/modulemd-subdocument-info-private.h"
 #include "private/modulemd-util.h"
@@ -308,6 +309,120 @@ mmd_emitter_scalar (yaml_emitter_t *emitter,
 }
 
 
+/**
+ * mmd_string_is_empty_or_a_number
+ * @string (in) (nullable)
+ *
+ * A purpose is to catch the strings which could be mistaken with a number.
+ *
+ * Returns: True if the @string is %NULL, empty, or looks like a number.
+ * False otherwise (looks like a string).
+ *
+ * Since 2.15
+ */
+static gboolean
+string_is_empty_or_a_number (const gchar *string)
+{
+  int fractional = 0;
+  int exponent = 0;
+  int hexadecimal = 0;
+  int octal = 0;
+
+  if (string == NULL)
+    return TRUE;
+  if (string[0] == '\0')
+    return TRUE;
+
+  if (!g_strcmp0 (string, ".nan"))
+    return TRUE; /* not a number symbol */
+  if (string[0] == '+' || string[0] == '-')
+    string++; /* accept a leading sign */
+  if (!g_strcmp0 (string, ".inf"))
+    return TRUE; /* infinity symbol */
+  if (string[0] == '.')
+    {
+      fractional = 1; /* accept a leading decimal point */
+      string++;
+    }
+  else if (string[0] == '0' && string[1] == 'x')
+    {
+      hexadecimal = 1;
+      string += 2;
+    }
+  else if (string[0] == '0' && string[1] == 'o')
+    {
+      octal = 1;
+      string += 2;
+    }
+  if (string[0] == '\0')
+    return FALSE; /* incomplete notation */
+
+  for (const gchar *character = string; *character != '\0'; character++)
+    {
+      if (hexadecimal)
+        {
+          if (!((*character >= '0' && *character <= '9') ||
+                (*character >= 'a' && *character <= 'f') ||
+                (*character >= 'A' && *character <= 'F')))
+            return FALSE;
+          continue;
+        }
+      else if (octal)
+        {
+          if (!(*character >= '0' && *character <= '7'))
+            return FALSE;
+          continue;
+        }
+      else /* decimal */
+        {
+          if (*character == '.')
+            {
+              if (fractional)
+                return FALSE; /* multiple decimal points */
+              else
+                {
+                  fractional = 1;
+                  continue;
+                }
+            }
+          if (fractional && (*character == 'e' || *character == 'E'))
+            {
+              if (exponent)
+                return FALSE; /* multiple franctional exponents */
+              else
+                {
+                  exponent = 1;
+                  continue;
+                }
+            }
+          if (exponent == 1 && (*character == '+' || *character == '-'))
+            {
+              exponent = 2; /* a sign of the exponent */
+              continue;
+            }
+          if (*character < '0' || *character > '9')
+            return FALSE;
+        }
+    }
+
+  return TRUE;
+}
+
+
+gboolean
+mmd_emitter_scalar_string (yaml_emitter_t *emitter,
+                           const gchar *scalar,
+                           GError **error)
+{
+  return mmd_emitter_scalar (emitter,
+                             scalar,
+                             string_is_empty_or_a_number (scalar) ?
+                               YAML_DOUBLE_QUOTED_SCALAR_STYLE :
+                               YAML_PLAIN_SCALAR_STYLE,
+                             error);
+}
+
+
 gboolean
 mmd_emitter_strv (yaml_emitter_t *emitter,
                   yaml_sequence_style_t seq_style,
@@ -329,8 +444,12 @@ mmd_emitter_strv (yaml_emitter_t *emitter,
 
   for (int i = 0; i < numentries; i++)
     {
-      ret = mmd_emitter_scalar (
-        emitter, list[i], YAML_PLAIN_SCALAR_STYLE, &nested_error);
+      ret = mmd_emitter_scalar (emitter,
+                                list[i],
+                                string_is_empty_or_a_number (list[i]) ?
+                                  YAML_DOUBLE_QUOTED_SCALAR_STYLE :
+                                  YAML_PLAIN_SCALAR_STYLE,
+                                &nested_error);
       if (!ret)
         {
           g_propagate_prefixed_error (
@@ -441,6 +560,16 @@ modulemd_yaml_parse_int64 (yaml_parser_t *parser, GError **error)
 
   if ((value == G_MAXINT64 && errno == ERANGE))
     {
+#ifdef HAVE_OVERFLOWED_BUILDORDER
+      /* A temporary hack. Remove when RHEL 8 goes end of life. */
+      if (g_str_equal ((const gchar *)event.data.scalar.value,
+                       "18446744073709551615"))
+        {
+          g_debug ("Coercing an invalid signed 64-bit integer to -1: %s",
+                   (const gchar *)event.data.scalar.value);
+          return -1;
+        }
+#endif
       g_set_error (error,
                    MODULEMD_YAML_ERROR,
                    MODULEMD_ERROR_VALIDATE,
@@ -581,15 +710,32 @@ modulemd_yaml_parse_string_set (yaml_parser_t *parser, GError **error)
         case YAML_SCALAR_EVENT:
           g_debug ("Parsing scalar: %s",
                    (const gchar *)event.data.scalar.value);
-          g_hash_table_add (result,
-                            g_strdup ((const gchar *)event.data.scalar.value));
 
-          if (!in_list)
+          if (in_list)
             {
-              /* We got a scalar instead of a sequence. Treat it as a list with
-               * a single entry
-               */
-              done = TRUE;
+              g_hash_table_add (
+                result, g_strdup ((const gchar *)event.data.scalar.value));
+            }
+          else
+            {
+              /* We got a scalar instead of a sequence. */
+              if (event.data.scalar.value && event.data.scalar.value[0])
+                {
+                  /* Treat it as a list with a single entry
+                   * if it's nonempty. */
+                  g_hash_table_add (
+                    result, g_strdup ((const gchar *)event.data.scalar.value));
+                  done = TRUE;
+                }
+              else
+                {
+                  /* Otherwise, it's an empty value node ("foo:") or an empty
+                   * string value node ("foo:''"), both which libyaml reports
+                   * as an empty string. Then keep the result hash table empty
+                   * as it's more helpful than a list with an empty string
+                   * which would be nevertheless invalid. */
+                  done = TRUE;
+                }
             }
           break;
 
@@ -845,7 +991,7 @@ modulemd_yaml_emit_nested_set (yaml_emitter_t *emitter,
     }
 
   keys = modulemd_ordered_str_keys (table, modulemd_strcmp_sort);
-  for (gint i = 0; i < keys->len; i++)
+  for (guint i = 0; i < keys->len; i++)
     {
       key = g_ptr_array_index (keys, i);
       dep = g_hash_table_lookup (table, key);
@@ -951,7 +1097,8 @@ modulemd_yaml_parse_document_type_internal (
               return FALSE;
             }
 
-          if (depth == 1 && g_str_equal (event.data.scalar.value, "document"))
+          if (depth == 1 &&
+              g_str_equal ((const gchar *)event.data.scalar.value, "document"))
             {
               if (doctype != MODULEMD_YAML_DOC_UNKNOWN)
                 {
@@ -1004,7 +1151,8 @@ modulemd_yaml_parse_document_type_internal (
               g_clear_pointer (&doctype_scalar, g_free);
             }
           else if (depth == 1 &&
-                   g_str_equal (event.data.scalar.value, "version"))
+                   g_str_equal ((const gchar *)event.data.scalar.value,
+                                "version"))
             {
               if (mdversion != 0)
                 {
@@ -1028,7 +1176,9 @@ modulemd_yaml_parse_document_type_internal (
                   return FALSE;
                 }
             }
-          else if (depth == 1 && g_str_equal (event.data.scalar.value, "data"))
+          else if (depth == 1 &&
+                   g_str_equal ((const gchar *)event.data.scalar.value,
+                                "data"))
             {
               had_data = TRUE;
             }
@@ -1222,7 +1372,8 @@ modulemd_yaml_emit_variant (yaml_emitter_t *emitter,
 
   if (g_variant_is_of_type (variant, G_VARIANT_TYPE_STRING))
     {
-      EMIT_SCALAR (emitter, error, g_variant_get_string (variant, NULL));
+      EMIT_SCALAR_STRING (
+        emitter, error, g_variant_get_string (variant, NULL));
     }
   else if (g_variant_is_of_type (variant, G_VARIANT_TYPE_BOOLEAN))
     {
@@ -1267,7 +1418,7 @@ modulemd_yaml_emit_variant (yaml_emitter_t *emitter,
                 "Got unexpected type while processing XMD dictionary.");
               return FALSE;
             }
-          EMIT_SCALAR (emitter, error, g_ptr_array_index (keys, i));
+          EMIT_SCALAR_STRING (emitter, error, g_ptr_array_index (keys, i));
           if (!modulemd_yaml_emit_variant (emitter, value, error))
             {
               return FALSE;
