@@ -96,7 +96,7 @@ module_index_test_dump (void)
   modulemd_module_stream_v1_set_description (
     MODULEMD_MODULE_STREAM_V1 (stream), "A test stream's description");
   modulemd_module_stream_v1_add_module_license (
-    MODULEMD_MODULE_STREAM_V1 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V1 (stream), "DUMMY1");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -110,7 +110,7 @@ module_index_test_dump (void)
   modulemd_module_stream_v2_set_description (
     MODULEMD_MODULE_STREAM_V2 (stream), "A second stream's description");
   modulemd_module_stream_v2_add_module_license (
-    MODULEMD_MODULE_STREAM_V2 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V2 (stream), "DUMMY2");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -167,7 +167,7 @@ module_index_test_dump (void)
                    "    A test stream's description\n"
                    "  license:\n"
                    "    module:\n"
-                   "    - Beerware\n"
+                   "    - DUMMY1\n"
                    "...\n"
                    "---\n"
                    "document: modulemd\n"
@@ -182,7 +182,7 @@ module_index_test_dump (void)
                    "    A second stream's description\n"
                    "  license:\n"
                    "    module:\n"
-                   "    - Beerware\n"
+                   "    - DUMMY2\n"
                    "...\n");
 }
 
@@ -305,6 +305,29 @@ module_index_test_read (void)
   g_clear_pointer (&failures, g_ptr_array_unref);
   g_clear_pointer (&error, g_error_free);
 
+  /* A stream that has nonsense in "data" with NULL error parameter.
+   * It makes sure that subdocument errors are reported independently
+   * from the global error. It used to crash. */
+  yaml_path =
+    g_strdup_printf ("%s/broken_stream.yaml", g_getenv ("TEST_DATA_PATH"));
+  g_assert_false (modulemd_module_index_update_from_file (
+    index, yaml_path, TRUE, &failures, NULL));
+  g_assert_cmpint (failures->len, ==, 1);
+  subdoc = g_ptr_array_index (failures, 0);
+  g_assert_error (modulemd_subdocument_info_get_gerror (subdoc),
+                  MODULEMD_YAML_ERROR,
+                  MMD_YAML_ERROR_PARSE);
+  g_assert_cmpstr (modulemd_subdocument_info_get_yaml (subdoc),
+                   ==,
+                   "---\n"
+                   "document: modulemd\n"
+                   "version: 2\n"
+                   "data: foobar\n"
+                   "...\n");
+  g_clear_pointer (&yaml_path, g_free);
+  g_clear_pointer (&failures, g_ptr_array_unref);
+  g_clear_pointer (&error, g_error_free);
+
   /* A non-existing file */
   yaml_path =
     g_strdup_printf ("%s/nothinghere.yaml", g_getenv ("TEST_DATA_PATH"));
@@ -463,6 +486,82 @@ module_index_test_read_unknown (void)
 }
 
 
+static void
+module_index_test_defaults_upgrade (void)
+{
+  g_autoptr (ModulemdModuleIndex) index = NULL;
+  g_autoptr (ModulemdDefaults) defaults = NULL;
+  gboolean retval;
+  g_autoptr (GError) error = NULL;
+
+  /* An index without any defaults starts with MD_DEFAULTS_VERSION_UNSET
+   * defaults version. */
+  index = modulemd_module_index_new ();
+  g_assert_cmpint (modulemd_module_index_get_defaults_mdversion (index),
+                   ==,
+                   MD_DEFAULTS_VERSION_UNSET);
+
+  /* Adding a modulemd-defaults-v1 sets defaults version of index to 1. */
+  defaults = modulemd_defaults_new (MD_DEFAULTS_VERSION_ONE, "foo");
+  retval = modulemd_module_index_add_defaults (index, defaults, NULL);
+  g_assert_true (retval);
+  g_assert_cmpint (modulemd_module_index_get_defaults_mdversion (index),
+                   ==,
+                   MD_DEFAULTS_VERSION_ONE);
+
+  /* Upgrading defaults of an index upgrades a version of the index and
+   * the versions of the particular defaults. */
+  retval = modulemd_module_index_upgrade_defaults (
+    index, MD_DEFAULTS_VERSION_LATEST, &error);
+  g_assert_true (retval);
+  g_assert_null (error);
+  g_assert_cmpint (modulemd_module_index_get_defaults_mdversion (index),
+                   ==,
+                   MD_DEFAULTS_VERSION_LATEST);
+  g_assert_cmpint (
+    modulemd_defaults_get_mdversion (modulemd_module_get_defaults (
+      modulemd_module_index_get_module (index, "foo"))),
+    ==,
+    MD_DEFAULTS_VERSION_LATEST);
+
+  /* Downgrading defaults of an index is forbidden. It returns an error and
+   * does not clobber the index. */
+  retval = modulemd_module_index_upgrade_defaults (
+    index, MD_DEFAULTS_VERSION_LATEST - 1, &error);
+  g_assert_false (retval);
+  g_assert_nonnull (error);
+  g_clear_error (&error);
+  g_assert_cmpint (modulemd_module_index_get_defaults_mdversion (index),
+                   ==,
+                   MD_DEFAULTS_VERSION_LATEST);
+  g_assert_cmpint (
+    modulemd_defaults_get_mdversion (modulemd_module_get_defaults (
+      modulemd_module_index_get_module (index, "foo"))),
+    ==,
+    MD_DEFAULTS_VERSION_LATEST);
+
+  /* Upgrading defaults of an index to an unsupported version fails. It returns
+   * an error and does not clobber the index. */
+  retval = modulemd_module_index_upgrade_defaults (
+    index, MD_DEFAULTS_VERSION_LATEST + 1, &error);
+  g_assert_false (retval);
+  g_assert_nonnull (error);
+  g_clear_error (&error);
+  g_assert_cmpint (modulemd_module_index_get_defaults_mdversion (index),
+                   ==,
+                   MD_DEFAULTS_VERSION_LATEST);
+  g_assert_cmpint (
+    modulemd_defaults_get_mdversion (modulemd_module_get_defaults (
+      modulemd_module_index_get_module (index, "foo"))),
+    ==,
+    MD_DEFAULTS_VERSION_LATEST);
+
+  /* A failure of upgrading a particular default in a range which is
+   * accaptable by the index should return an error. But there is now way of
+   * testing it. */
+}
+
+
 static void
 module_index_test_stream_upgrade (void)
 {
@@ -486,7 +585,7 @@ module_index_test_stream_upgrade (void)
   modulemd_module_stream_v1_set_description (
     MODULEMD_MODULE_STREAM_V1 (stream), "A test stream's description");
   modulemd_module_stream_v1_add_module_license (
-    MODULEMD_MODULE_STREAM_V1 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V1 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -518,7 +617,7 @@ module_index_test_stream_upgrade (void)
   modulemd_module_stream_v2_set_description (
     MODULEMD_MODULE_STREAM_V2 (stream), "A second stream's description");
   modulemd_module_stream_v2_add_module_license (
-    MODULEMD_MODULE_STREAM_V2 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V2 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -541,7 +640,7 @@ module_index_test_stream_upgrade (void)
   modulemd_module_stream_v1_set_description (
     MODULEMD_MODULE_STREAM_V1 (stream), "A test stream's description");
   modulemd_module_stream_v1_add_module_license (
-    MODULEMD_MODULE_STREAM_V1 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V1 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -573,7 +672,7 @@ module_index_test_stream_upgrade (void)
   modulemd_module_stream_v2_set_description (
     MODULEMD_MODULE_STREAM_V2 (stream), "A second stream's description");
   modulemd_module_stream_v2_add_module_license (
-    MODULEMD_MODULE_STREAM_V2 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V2 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -625,7 +724,7 @@ module_index_test_index_upgrade (void)
   modulemd_module_stream_v1_set_description (
     MODULEMD_MODULE_STREAM_V1 (stream), "A test stream's description");
   modulemd_module_stream_v1_add_module_license (
-    MODULEMD_MODULE_STREAM_V1 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V1 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -657,7 +756,7 @@ module_index_test_index_upgrade (void)
   modulemd_module_stream_v1_set_description (
     MODULEMD_MODULE_STREAM_V1 (stream), "A test stream's description");
   modulemd_module_stream_v1_add_module_license (
-    MODULEMD_MODULE_STREAM_V1 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V1 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -772,7 +871,7 @@ module_index_test_index_upgrade (void)
   modulemd_module_stream_v2_set_description (
     MODULEMD_MODULE_STREAM_V2 (stream), "A test stream's description");
   modulemd_module_stream_v2_add_module_license (
-    MODULEMD_MODULE_STREAM_V2 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V2 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -804,7 +903,7 @@ module_index_test_index_upgrade (void)
   modulemd_module_stream_v2_set_description (
     MODULEMD_MODULE_STREAM_V2 (stream), "A test stream's description");
   modulemd_module_stream_v2_add_module_license (
-    MODULEMD_MODULE_STREAM_V2 (stream), "Beerware");
+    MODULEMD_MODULE_STREAM_V2 (stream), "DUMMY");
   ret = modulemd_module_index_add_module_stream (index, stream, &error);
   g_assert_no_error (error);
   g_assert_true (ret);
@@ -962,7 +1061,7 @@ custom_string_read_handler (void *data,
       return 1;
     }
 
-  if (size > (size_t) (end - custom->current))
+  if (size > (size_t)(end - custom->current))
     {
       size = end - custom->current;
     }
@@ -990,7 +1089,7 @@ module_index_test_custom_read (void)
 "version: 2\n"
 "data:\n"
 "  name: testmodule\n"
-"  stream: master\n"
+"  stream: main\n"
 "  version: 20180405123256\n"
 "  context: c2c572ec\n"
 "  arch: x86_64\n"
@@ -1000,10 +1099,9 @@ module_index_test_custom_read (void)
 "    testing the build and release pipeline.\n"
 "  license:\n"
 "    module:\n"
-"    - MIT\n"
+"    - DUMMY\n"
 "    content:\n"
-"    - GPL+ or Artistic\n"
-"    - MIT\n"
+"    - DUMMY\n"
 "  xmd:\n"
 "    mbs:\n"
 "      scmurl: https://src.fedoraproject.org/modules/testmodule.git?#0d33e028e4561f82ea43f670ee6366675cd6a6fe\n"
@@ -1049,7 +1147,7 @@ module_index_test_custom_read (void)
 "        rationale: A dependency of tangerine.\n"
 "        repository: git://pkgs.fedoraproject.org/rpms/perl-List-Compare\n"
 "        cache: http://pkgs.fedoraproject.org/repo/pkgs/perl-List-Compare\n"
-"        ref: master\n"
+"        ref: main\n"
 "      perl-Tangerine:\n"
 "        rationale: Provides API for this module and is a dependency of tangerine.\n"
 "        repository: git://pkgs.fedoraproject.org/rpms/perl-Tangerine\n"
@@ -1059,7 +1157,7 @@ module_index_test_custom_read (void)
 "        rationale: Provides API for this module.\n"
 "        repository: git://pkgs.fedoraproject.org/rpms/tangerine\n"
 "        cache: http://pkgs.fedoraproject.org/repo/pkgs/tangerine\n"
-"        ref: master\n"
+"        ref: main\n"
 "        buildorder: 10\n"
 "  artifacts:\n"
 "    rpms:\n"
@@ -1107,7 +1205,7 @@ module_index_test_custom_write (void)
 "version: 2\n"
 "data:\n"
 "  name: testmodule\n"
-"  stream: master\n"
+"  stream: main\n"
 "  version: 20180405123256\n"
 "  context: c2c572ec\n"
 "  arch: x86_64\n"
@@ -1117,10 +1215,9 @@ module_index_test_custom_write (void)
 "    testing the build and release pipeline.\n"
 "  license:\n"
 "    module:\n"
-"    - MIT\n"
+"    - DUMMY\n"
 "    content:\n"
-"    - GPL+ or Artistic\n"
-"    - MIT\n"
+"    - DUMMY\n"
 "  xmd:\n"
 "    mbs:\n"
 "      scmurl: https://src.fedoraproject.org/modules/testmodule.git?#0d33e028e4561f82ea43f670ee6366675cd6a6fe\n"
@@ -1166,7 +1263,7 @@ module_index_test_custom_write (void)
 "        rationale: A dependency of tangerine.\n"
 "        repository: git://pkgs.fedoraproject.org/rpms/perl-List-Compare\n"
 "        cache: http://pkgs.fedoraproject.org/repo/pkgs/perl-List-Compare\n"
-"        ref: master\n"
+"        ref: main\n"
 "      perl-Tangerine:\n"
 "        rationale: Provides API for this module and is a dependency of tangerine.\n"
 "        repository: git://pkgs.fedoraproject.org/rpms/perl-Tangerine\n"
@@ -1176,7 +1273,7 @@ module_index_test_custom_write (void)
 "        rationale: Provides API for this module.\n"
 "        repository: git://pkgs.fedoraproject.org/rpms/tangerine\n"
 "        cache: http://pkgs.fedoraproject.org/repo/pkgs/tangerine\n"
-"        ref: master\n"
+"        ref: main\n"
 "        buildorder: 10\n"
 "  artifacts:\n"
 "    rpms:\n"
@@ -1302,7 +1399,6 @@ test_module_index_read_compressed (void)
   g_autofree gchar *compressed_text = NULL;
 
 #ifdef HAVE_RPMIO
-#ifdef HAVE_LIBMAGIC
   struct expected_compressed_read_t expected[] = {
     {
       .filename = "bzipped",
@@ -1318,29 +1414,6 @@ test_module_index_read_compressed (void)
     { .filename = "xzipped.yaml.xz", .succeeds = TRUE },
     { .filename = NULL }
   };
-#else /* HAVE_LIBMAGIC */
-  struct expected_compressed_read_t expected[] = {
-    { .filename = "bzipped",
-      .succeeds = FALSE,
-      .error_domain = MODULEMD_YAML_ERROR,
-      .error_code = MMD_YAML_ERROR_UNPARSEABLE },
-    {
-      .filename = "bzipped.yaml.bz2",
-      .succeeds = TRUE,
-    },
-    { .filename = "gzipped",
-      .succeeds = FALSE,
-      .error_domain = MODULEMD_YAML_ERROR,
-      .error_code = MMD_YAML_ERROR_UNPARSEABLE },
-    { .filename = "gzipped.yaml.gz", .succeeds = TRUE },
-    { .filename = "xzipped",
-      .succeeds = FALSE,
-      .error_domain = MODULEMD_YAML_ERROR,
-      .error_code = MMD_YAML_ERROR_UNPARSEABLE },
-    { .filename = "xzipped.yaml.xz", .succeeds = TRUE },
-    { .filename = NULL }
-  };
-#endif /* HAVE_LIBMAGIC */
 
 #else /* HAVE_RPMIO */
   struct expected_compressed_read_t expected[] = {
@@ -1452,7 +1525,6 @@ test_module_index_read_def_dir (void)
 {
   gboolean ret;
   g_autoptr (ModulemdModuleIndex) idx = modulemd_module_index_new ();
-  g_autoptr (GPtrArray) failures = NULL;
   g_autoptr (GError) error = NULL;
   g_autofree gchar *path =
     g_build_path ("/", g_getenv ("TEST_DATA_PATH"), "defaults", NULL);
@@ -1876,6 +1948,9 @@ main (int argc, char *argv[])
   g_test_add_func ("/modulemd/v2/module/index/read/unknown",
                    module_index_test_read_unknown);
 
+  g_test_add_func ("/modulemd/v2/module/index/upgrade/defaults",
+                   module_index_test_defaults_upgrade);
+
   g_test_add_func ("/modulemd/v2/module/index/upgrade/stream",
                    module_index_test_stream_upgrade);
 
